@@ -5,7 +5,7 @@
 """
 Tweepy Twitter API library
 """
-__version__ = '2.1'
+__version__ = '2.3'
 __author__ = 'Joshua Roesslein'
 __license__ = 'MIT'
 
@@ -13,7 +13,7 @@ from tweepy.models import Status, User, DirectMessage, Friendship, SavedSearch,
 from tweepy.error import TweepError
 from tweepy.api import API
 from tweepy.cache import Cache, MemoryCache, FileCache
-from tweepy.auth import BasicAuthHandler, OAuthHandler
+from tweepy.auth import OAuthHandler
 from tweepy.streaming import Stream, StreamListener
 from tweepy.cursor import Cursor
 
